@@ -164,6 +164,10 @@ class User:
         threadlog.info("setting password for user %r", self.name)
 
     def delete(self):
+        # delete all projects on the index
+        for name in self.get().get("indexes", {}):
+            self.getstage(name).delete()
+        # delete the user information itself
         self.key.delete()
         with self.keyfs.USERLIST.update() as userlist:
             userlist.remove(self.name)
@@ -319,7 +323,8 @@ class BaseStage:
                 return stage.get_projectname_perstage(name) and \
                        (not private_hit or whitelisted)
             private_hit = private_hit or bool(self.get_projectname_perstage(name))
-            whitelisted = whitelisted or name in stage.ixconfig["pypi_whitelist"]
+            whitelist = set(stage.ixconfig["pypi_whitelist"])
+            whitelisted = whitelisted or '*' in whitelist or name in whitelist
 
     def op_sro(self, opname, **kw):
         for stage in self._sro():
@@ -338,7 +343,8 @@ class BaseStage:
                     threadlog.debug("private package %r whitelisted at stage %s",
                                     projectname, whitelisted.name)
             else:
-                if projectname in stage.ixconfig["pypi_whitelist"]:
+                whitelist = set(stage.ixconfig["pypi_whitelist"])
+                if '*' in whitelist or projectname in whitelist:
                     whitelisted = stage
             res = getattr(stage, opname)(**kw)
             private_hit = private_hit or res
@@ -426,9 +432,6 @@ class PrivateStage(BaseStage):
     #class MetadataExists(Exception):
     #    """ metadata exists on a given non-volatile index. """
 
-    class RegisterNameConflict(Exception):
-        """ a conflict while trying to register metadata. """
-
     def get_projectname_perstage(self, name):
         """ return existing projectname for the given name which may
         be in a non-canonical form. """
@@ -450,9 +453,10 @@ class PrivateStage(BaseStage):
         projectname = self.get_projectname(name)
         log = thread_current_log()
         if projectname is not None and projectname != name:
-            log.error("project %r has other name %r in stage %s" %(
-                      name, projectname, self.name))
-            raise self.RegisterNameConflict(projectname)
+            log.warn("using already registered name %r for submitted %r "
+                     "in stage %r" %(
+                      projectname, name, self.name))
+            metadata["name"] = projectname
         self._set_versiondata(metadata)
 
     def key_projversions(self, name):
@@ -535,7 +539,14 @@ class PrivateStage(BaseStage):
                           last_modified=None):
         filename = ensure_unicode(filename)
         if not self.get_versiondata(name, version):
-            raise MissesRegistration("%s-%s", name, version)
+            # There's a chance the version was guessed from the
+            # filename, which might have swapped dashes to underscores
+            if '_' in version:
+                version = version.replace('_', '-')
+                if not self.get_versiondata(name, version):
+                    raise MissesRegistration("%s-%s", name, version)
+            else:
+                raise MissesRegistration("%s-%s", name, version)
         threadlog.debug("project name of %r is %r", filename, name)
         linkstore = self.get_linkstore_perstage(name, version)
         entry = linkstore.create_linked_entry(
